@@ -35,7 +35,7 @@ def load_properties_after_started(app):
         from client import do_service
         for conf in configs:
             r = do_service(f"{conf}-{config.config_profile}.yml", app_name=config.config_server_id,
-                           return_type="str", auth=False)       # 这里是从配置中心去获取数据,不做auth
+                           return_type="str", auth=False)  # 这里是从配置中心去获取数据,不做auth
             # 配置中心的配置文件不存在时，返回的是 '{}'
             if r is not None and str(r).rstrip() != '{}':
                 from config import annotation
@@ -59,7 +59,7 @@ def load_properties_after_started(app):
 
 def _exists_bootstrap_property(app):
     from registry import read_yaml_file
-    yml = read_yaml_file(app, "bootstrap.yml")
+    yml = read_yaml_file(app, "bootstrap.yml", config.spring_profiles_active)
     return yml
 
 
@@ -123,6 +123,19 @@ def init_from_yaml_property(app):
     return True
 
 
+def init_profile_from_environ_property():
+    import os
+
+    environs = os.environ
+
+    if "spring.profiles.active" in environs:
+        config.spring_profiles_active = environs["spring.profiles.active"]
+        log.info(f"从系统环境变量中获取到spring.profiles.active:{config.spring_profiles_active}")
+    elif "SPRING_PROFILES_ACTIVE" in environs:
+        config.spring_profiles_active = environs["SPRING_PROFILES_ACTIVE"]
+        log.info(f"从系统环境变量中获取到SPRING_PROFILES_ACTIVE:{config.spring_profiles_active}")
+
+
 def init_from_environ_property():
     import os
 
@@ -192,7 +205,7 @@ def _read_from_application_yaml_property(app):
     :return:
     """
     from registry import read_yaml_file
-    yml = read_yaml_file(app, "application.yml")
+    yml = read_yaml_file(app, "application.yml", config.spring_profiles_active)
     if yml is None:
         # 说明没有yml文件,不进行注册处理
         log.info("没有配置application.yml,采用默认的配置信息")
