@@ -43,8 +43,8 @@ eureka_client.init(eureka_server=config.eureka_default_zone,
                    ha_strategy=eureka_client.HA_STRATEGY_STICK,
                    status_page_url="/actuator/info",
                    health_check_url="/actuator/health",
-                   renewal_interval_in_secs=2,
-                   duration_in_secs=6)
+                   renewal_interval_in_secs=4,
+                   duration_in_secs=12)
 
 log.info("服务启动,完成注册中心注册及心跳")
 
@@ -76,6 +76,7 @@ log.info("服务启动,完成规则引擎的初始化")
 try:
     if annotation.get_value("${celery.enable:false}"):
         import cloudcelery
+
         log.info("服务启动,完成celery的预启动")
 except:
     # 无所谓
@@ -85,7 +86,8 @@ except:
 try:
     import handlers
 except Exception as e:
-    log.error(f"加载执行器实例错误,忽略:{str(e)}")
+    log.error(f"加载执行器实例错误:{str(e)}")
+    exit(-1)  # 程序直接退出
 log.info("服务启动,完成处理器的预加载")
 
 # 程序启动后,判断是否需要注册执行器
@@ -104,24 +106,12 @@ log.info("服务启动,完成日期清理线程的启动")
 log.info(f"服务启动:{config.server_ip or config.find_host_ip()}:{config.server_port or 5000}")
 log.info("======服务启动完毕======")
 
+from multiprocessing import Process
 
-from multiprocessing import  Process
-class FlaskProcess(Process): #继承Process类
-    def __init__(self,name):
-        super(FlaskProcess,self).__init__()
-        self.name = name
 
-    def run(self):
-        from config import server_port
-        from gevent import pywsgi
-        # import gevent.monkey
-        # gevent.monkey.patch_all()
-        server = pywsgi.WSGIServer(('0.0.0.0', server_port), app)
-        server.serve_forever()
-
-class CeleryProcess(Process): #继承Process类
-    def __init__(self,name):
-        super(CeleryProcess,self).__init__()
+class CeleryProcess(Process):  # 继承Process类
+    def __init__(self, name):
+        super(CeleryProcess, self).__init__()
         self.name = name
 
     def run(self):
@@ -134,29 +124,32 @@ class CeleryProcess(Process): #继承Process类
         import cloudcelery
         cloudcelery.celery.worker_main(argv)
 
+
 def run_flask():
     """
     单独启动flask
     :return:
     """
-    p1 = FlaskProcess('Flask')
-    p1.start()
-    p1.join()
+    from config import server_port
+    from gevent import pywsgi
+    # import gevent.monkey
+    # gevent.monkey.patch_all()
+    server = pywsgi.WSGIServer(('0.0.0.0', server_port), app)
+    server.serve_forever()
+
 
 def run_flask_with_celery():
     """
     启动flask和celery
     :return:
     """
-    p1 = FlaskProcess('Flask')
     p2 = CeleryProcess('Celery')
-
-    p1.start()
     p2.start()
 
-    p1.join()
+    run_flask()
     p2.join()
 
+
 def run_with_auto_select():
     if annotation.get_value("${celery.enable:false}"):
         run_flask_with_celery()
